@@ -26,7 +26,14 @@
 #include <memory.h>
 
 #ifdef MAC_OS_X
+
+/* this seems to give wrong results on intel macs :( */
 #include <machine/endian.h>
+
+/* doing this doesn't seem to fix it, and would presumably break it on */
+/* powerpc macs (but are we otherwise supported there?) */
+/*#define __BYTE_ORDER __LITTLE_ENDIAN */
+
 #else
 #include <endian.h>
 #endif
@@ -149,7 +156,14 @@ void config_audio_device(int rate_set, int bits_set, int stereo_set)
     /* play everything as 16 bit, signed integers */
     /* using the appropriate endianness */
 
-#if __BYTE_ORDER == __BIG_ENDIAN
+/* Alister: I have swapped this around as an intel mac seems to think */
+/* the first test is true regardless of whether you test for BE or LE */
+/* Presumably it might fail on a powerpc mac now?                     */
+/* Also, does it break other platforms (since LE is normal these days */
+/* it should really stay default                                      */
+#if __BYTE_ORDER == __LITTLE_ENDIAN
+    format_set = GWC_S16_LE ;
+#elif __BYTE_ORDER == __BIG_ENDIAN
     format_set = GWC_S16_BE ;
 #else
     format_set = GWC_S16_LE ;
@@ -1218,7 +1232,7 @@ void flush_wavefile_data(void)
 }
 
 /* process_audio for mac_os_x is found in the audio_osx.c */
-#ifndef MAC_OS_X
+#if !defined MAC_OS_X || defined HAVE_PULSE_AUDIO
 int process_audio(gfloat *pL, gfloat *pR)
 {
     int len = 0 ;
@@ -1291,7 +1305,11 @@ int process_audio(gfloat *pL, gfloat *pR)
 
     for(frame = 0  ; frame < n_read ; frame++) {
 	int vl, vr ;
-	i = frame*2 ;
+	// I don't understand how all this code works, but if I remove the multiplication by two then the level meter actually works for mono files in ALSA, and for some reason there seem to be no side effects.
+	// However, note that the level meters work quite differently in different configurations, and arguably don't show anything helpful, anyway.
+	// Perhaps we should multiply by (stereo + 1) though?
+	// i = frame*2 ;
+	i = frame;
 
 	if(BYTESPERSAMPLE < 3) {
 	    if(feather_out == 1 && n_read-(frame+1) < FEATHER_WIDTH) {
